Sync to Wine:

date: 2005/02/25 14:07:56
Jon Griffiths <jon_p_griffiths@yahoo.com>
Documentation spelling fixes.
Modified: trunk/reactos/subsys/system/winefile/winefile.c

Modified: trunk/reactos/subsys/system/winefile/winefile.c
--- trunk/reactos/subsys/system/winefile/winefile.c	2005-05-11 14:46:42 UTC (rev 15213)
+++ trunk/reactos/subsys/system/winefile/winefile.c	2005-05-11 14:49:24 UTC (rev 15214)
@@ -2205,7 +2205,7 @@
 static void draw_item(Pane* pane, LPDRAWITEMSTRUCT dis, Entry* entry, int calcWidthCol);
 
 
 /* calculate prefered width for all visible columns */
 
 static BOOL calc_widths(Pane* pane, BOOL anyway)
 {
@@ -2292,7 +2292,7 @@
 }
 
 
 /* calculate one prefered column width */
 
 static void calc_single_width(Pane* pane, int col)
 {
@@ -3396,7 +3396,7 @@
 			break;
 
 #ifndef _NO_EXTENSIONS
-		case ID_PREFERED_SIZES: {
+		case ID_PREFERRED_SIZES: {
 			calc_widths(pane, TRUE);
 			set_header(pane);
 			InvalidateRect(pane->hwnd, 0, TRUE);
@@ -2205,7 +2205,7 @@
 
 
-/* calculate prefered width for all visible columns */
+/* calculate preferred width for all visible columns */
 
 static BOOL calc_widths(Pane* pane, BOOL anyway)
@@ -2292,7 +2292,7 @@
 
 
-/* calculate one prefered column width */
+/* calculate one preferred column width */
 
 static void calc_single_width(Pane* pane, int col)